==========================================
``psyclone.domain.common.algorithm.psyir``
==========================================

.. automodule:: psyclone.domain.common.algorithm.psyir

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.common.algorithm.psyir


Classes
=======

- :py:class:`AlgorithmInvokeCall`:
  An invoke call in a PSyclone Algorithm layer.

- :py:class:`KernelFunctor`:
  Object containing a kernel call, a description of its required


.. autoclass:: AlgorithmInvokeCall
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: AlgorithmInvokeCall
      :parts: 1

.. autoclass:: KernelFunctor
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: KernelFunctor
      :parts: 1
